@@ -7,11 +7,11 @@ Elive -  Elluminate Live! (c) client library
 
 =head1 VERSION
 
-Version 0.41
+Version 0.42
 
 =cut
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Class::Data::Inheritable;
 use base qw{Class::Data::Inheritable};
@@ -60,8 +60,8 @@ achieved via the SOAP API. This is known as the I<Command Toolkit> and
 is detailed in chapter 4 of the Elluminate I<Live!> Software Developers
 Kit.
 
-This module provides Perl object to entity bindings to Elluminate I<Live!>
-databases via the command toolkit.
+This module provides Perl object to bindings to Elluminate I<Live!> entities
+via the command toolkit.
 
 =cut
 
@@ -328,8 +328,8 @@ Elluminate Services Errors:
 This may indicate that the particular command adaptor is is not available for
 your site instance.
 
-Check that your Elluminate I<Live!> server software version; Elive supports
-9.0 and 9.1.
+Check that your Elluminate I<Live!> server software version; This module
+has been tested against 9.0, 9.1 and 9.5.2
 
 If the problem persists, the command entry may be missing from your site
 configuration file. Please follow the instructions in the README file
@@ -390,6 +390,28 @@ elive_query is an example simple sql-like script. It is a basic program
 for listing and retrieving entities. It serves as a simple demonstration
 script, and can be used to confirm basic operation of Elive.
 
+It servers a secondary function of querying entity metadata. For example,
+to show the user entity:
+
+    $> elive_query
+    Elive query 0.xx  - type 'help' for help
+
+    elive> show
+    usage: show group|meeting|meetingParameters|participantList|preload|recording|serverDetails|serverParameters|use
+
+    elive> show meeting
+    meeting: Elive::Entity::Meeting:
+      meetingId          : pkey Int        
+      allModerators      : Bool      -- all participants can moderate
+      deleted            : Bool            
+      end                : HiResDate -- meeting end time
+      facilitatorId      : Str       -- userId of facilitator
+      name               : Str       -- meeting name
+      password           : Str       -- meeting password
+      privateMeeting     : Bool      -- don't display meeting in public schedule
+      restrictedMeeting  : Bool      -- Restricted meeting
+      start              : HiResDate -- meeting start time
+
 =head2 elive_raise_meeting
 
 This is a demonstration script to create a meeting, set options, assign
@@ -474,7 +496,8 @@ Describes setting up multiple site instances.
 
 The Elluminate I<Live!> advanced configuration guide mentions that it can be
 configured to use other databases that support a JDBC bridge (most databases
-in widespread use do). It specifically mentions SQL Server or Oracle. 
+in widespread use). It specifically mentions SQL Server or Oracle. MySQL
+is supported with 9.5.0 
 
 =item LDAP Authentication
 
@@ -502,8 +525,8 @@ David Warring, C<< <david.warring at gmail.com> >>
 
 =item Elive is a newish module
 
-I have so far run it against a limited number of Elluminate 9.0 and 9.1
-installations.
+I have so far run it against a limited number of Elluminate 9.0, 9.1
+and 9.5 installations.
 
 So far it does not implement all SOAP calls, but concentrates on entities
 such as users, meetings, preloads and meeting participants.
